@@ -292,7 +292,7 @@ class I2AOauth2Client:
             raise I2AOauth2ClientException(data=response.json())
 
     def server_to_server_password_reset_request(self, email):
-        url = self._get_full_url('server-to-server/password-reset-request/')
+        url = self._get_full_url('server-to-server/application-users/password-reset-request/')
         data = {
             "username": email
         }
@@ -307,7 +307,7 @@ class I2AOauth2Client:
             raise I2AOauth2ClientException(data=response.json())
 
     def server_to_server_password_reset(self, code, new_password1, new_password2):
-        url = self._get_full_url('server-to-server/password-reset/')
+        url = self._get_full_url('server-to-server/application-users/password-reset/')
         data = {
             "code": str(code),
             "new_password1": new_password1,
@@ -324,7 +324,7 @@ class I2AOauth2Client:
             raise I2AOauth2ClientException(data=response.json())
 
     def server_to_server_password_reset_code_check(self, code):
-        url = self._get_full_url('server-to-server/password-reset-code-check/')
+        url = self._get_full_url('server-to-server/application-users/password-reset-code-check/')
         data = {
             "code": str(code)
         }
